summaryrefslogtreecommitdiffstats
path: root/perl-install/network/test.pm
diff options
context:
space:
mode:
Diffstat (limited to 'perl-install/network/test.pm')
-rw-r--r--perl-install/network/test.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/perl-install/network/test.pm b/perl-install/network/test.pm
index 7c25fce05..435e8a676 100644
--- a/perl-install/network/test.pm
+++ b/perl-install/network/test.pm
@@ -8,7 +8,7 @@ use Socket;
sub new {
my ($class, $o_hostname) = @_;
bless {
- hostname => $o_hostname || "mandrakesoft.com"
+ hostname => $o_hostname || "mandriva.com"
}, $class;
}
@@ -111,7 +111,7 @@ sub update_status {
=head2 Test synchronously
#- resolve and get ping to hostname from command line if given, else to Mandrakesoft
use lib qw(/usr/lib/libDrakX);
use network::test;
@@ -131,7 +131,7 @@ ping to host: $ping
=head2 Test asynchronously
#- resolve and get ping to hostname from command line if given, else to Mandrakesoft
#- prints a "." every 10 miliseconds during connection test
use lib qw(/usr/lib/libDrakX);
use network::test;
@@ -111,7 +111,7 @@ sub update_status {
=head2 Test synchronously
-#- resolve and get ping to hostname from command line if given, else to Mandrakesoft
+#- resolve and get ping to hostname from command line if given, else to Mandriva
use lib qw(/usr/lib/libDrakX);
use network::test;
@@ -131,7 +131,7 @@ ping to host: $ping
=head2 Test asynchronously
-#- resolve and get ping to hostname from command line if given, else to Mandrakesoft
+#- resolve and get ping to hostname from command line if given, else to Mandriva
#- prints a "." every 10 miliseconds during connection test
use lib qw(/usr/lib/libDrakX);